@@ -1,6 +1,6 @@
 '''Interactive Assembler'''
 
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 _author = 'Di Paola Martin'
 _license = 'GNU GPLv3'
@@ -24,5 +24,5 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 try:
     from .iasm import main
-except SystemError:
+except (SystemError, ImportError):
     pass  # this happens when importing from setup.py
