@@ -58,6 +58,15 @@ def build_argparser():
         help='memory allocated for code.'
     )
 
+    parser.add_argument(
+        "--program-counter",
+        metavar='<pc>',
+        dest='pc_addr',
+        required=False,
+        default=0x1000000,
+        help='starting program counter address.'
+    )
+
     parser.add_argument(
         "--style",
         metavar='<style>',
@@ -65,7 +74,7 @@ def build_argparser():
         required=False,
         default='paraiso-dark',
         help='style for the prompt.',
-        choices=list(sorted(get_all_styles()))
+        choices=sorted(list(get_all_styles()) + ['none'])
     )
 
     parser.add_argument(
@@ -116,6 +125,23 @@ def build_argparser():
         help='version of the ISA.'
     )
 
+    parser.add_argument(
+        "--simple-prompt",
+        action='store_true',
+        dest='simple_prompt',
+        required=False,
+        default=False,
+        help='simpler alternative prompt.'
+    )
+
+    parser.add_argument(
+        "--no-history",
+        action='store_true',
+        required=False,
+        default=False,
+        help='disable shell history of the commands.'
+    )
+
     parser.add_argument(
         '-V',
         '--version',
